Learn R Programming

splineCox (version 0.0.8)

spline.copula.MLE: Maximum likelihood estimation for spline copula parameter matrix

Description

Performs maximum likelihood estimation of the 5x5 spline copula parameter matrix \(R\) using an EM-type algorithm based on M-spline basis functions.

Usage

spline.copula.MLE(U, V, E1 = 0.001, E2 = 0.001, R0 = NULL)

Value

A list containing:

R

Estimated 5x5 spline copula parameter matrix.

R0

Initial matrix used to start the algorithm.

convergence

Matrix recording the iteration number and corresponding log-likelihood values.

Arguments

U

Numeric vector of length \(n\) with values in (0, 1).

V

Numeric vector of length \(n\) with values in (0, 1).

E1

Positive scalar specifying the convergence tolerance for the outer EM iteration updating \(R\).

E2

Positive scalar specifying the convergence tolerance for the inner iteration updating auxiliary parameters.

R0

Optional 5x5 numeric matrix providing initial values for \(R\). If NULL, a data-driven initialization is used.

Details

The algorithm alternates between updating the spline copula parameter matrix and auxiliary parameters until convergence criteria are satisfied.

Examples

Run this code
n <- 100
R <- matrix(c(1,0,0,0,0,
              0,2,0,0,0,
              0,0,2,0,0,
              0,0,0,2,0,
              0,0,0,0,1)/8, 5, 5, byrow = TRUE)
out <- spline.copula.simu(n, R = R)
fit <- spline.copula.MLE(out$U, out$V)

Run the code above in your browser using DataLab